# {py:mod}`lastuuid.dummies`

```{py:module} lastuuid.dummies
```

```{autodoc2-docstring} lastuuid.dummies
:parser: myst
:allowtitles:
```

## Module Contents

### Data

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`uuid7gen <lastuuid.dummies.uuid7gen>`
  - ```{autodoc2-docstring} lastuuid.dummies.uuid7gen
    :parser: myst
    :summary:
    ```
* - {py:obj}`uuidgen <lastuuid.dummies.uuidgen>`
  - ```{autodoc2-docstring} lastuuid.dummies.uuidgen
    :parser: myst
    :summary:
    ```
````

### API

````{py:data} uuid7gen
:canonical: lastuuid.dummies.uuid7gen
:value: >
   'LastUUIDFactory(...)'

```{autodoc2-docstring} lastuuid.dummies.uuid7gen
:parser: myst
```

````

````{py:data} uuidgen
:canonical: lastuuid.dummies.uuidgen
:value: >
   'LastUUIDFactory(...)'

```{autodoc2-docstring} lastuuid.dummies.uuidgen
:parser: myst
```

````
